// Module class ---------------------------------------------------------------

function Module(title, lectureItems) {
	this.title = title;

	this.lectures = this.loadLectures(lectureItems);
}

Module.prototype.loadLectures = function(lectureItems) {

	var lectureArray = new Array();
	this.slideCount = 0;

	for (var i=0; i<lectureItems.length ; i++) {
		var lectureItem = lectureItems[i];

		var lectureId = _getAttribute(lectureItem, "identifier");
		var lectureTitleNode = _getFirstElement(lectureItem, "title");

		//alert("LTN -> " + lectureTitleNode);

		var lectureTitle = _getElementText(lectureTitleNode);

		//alert(lectureTitle);
		var slideItems = _getChildNodesByName(lectureItem, "item");
		lectureArray[lectureArray.length] = new Lecture(lectureId, lectureTitle, slideItems, i);

		
		this.slideCount += slideItems.length; 
	}

	return lectureArray;
}

Module.prototype.getTitle = function() {
	return this.title;
}

Module.prototype.getLectures = function() {
	return this.lectures;
}

Module.prototype.getSlideById = function(slideId) {
	
	for (var i=0; i<this.lectures.length ; i++ ) {

		// napr. slideId = I_1_4 and lectureId = I_1
		var lecture = this.lectures[i];

		if (slideId.indexOf(lecture.getId() + "_") != -1 ) {
			return lecture.getSlideById(slideId);
		}
	}
}

Module.prototype.getLectureBySlideId = function(slideId) {
	
	for (var i=0; i<this.lectures.length ; i++ ) {

		// napr. slideId = I_1_4 and lectureId = I_1
		var lecture = this.lectures[i];

		if (slideId.indexOf(lecture.getId() + "_") != -1 ) {
			return lecture;
		}
	}
}

Module.prototype.getLectureByOrder = function(order) {
	return this.lectures[order];
}

Module.prototype.getLecturesCount = function(order) {
	return this.lectures.length;
}

Module.prototype.getSlideCount = function() {
	return this.slideCount;
}

Module.prototype.getAllKeywords = function() {

	var _allKwrds = new Array();

	for (var i=0 ; i<this.lectures.length ; i++) {
		var _kwrds = this.lectures[i].getAllKeywords();

		for (var j=0; j<_kwrds.length ; j++ ) {
			if (!_contains(_allKwrds, _kwrds[j])) {
				_allKwrds[_allKwrds.length] = _kwrds[j];
			}
		}
	}

	_allKwrds.sort(_sortString);

	return _allKwrds;
}

Module.prototype.hasKeywords = function() {
	return (this.getAllKeywords().length != 0) ? true : false;
}

Module.prototype.getSlidesIdByKwrd = function(kwrd) {
	
	var allSlidesId = new Array();

	for (var i=0 ; i<this.lectures.length ; i++) {
		var slidesId = this.lectures[i].getSlidesIdByKwrd(kwrd);

		for (var j=0; j<slidesId.length ; j++ ) {
			allSlidesId[allSlidesId.length] = slidesId[j];
		}

	}

	return allSlidesId;
}

// Lecture class ----------------------------------------------------------------

function Lecture(id, title, slideItems, order) {
	this.id = id;
	this.title = title;

	this.slides = this.loadSlides(slideItems);

	this.order = order;
}

Lecture.prototype.loadSlides = function(slideItems) {

	var slideArray = new Array();

	for (var i=0; i<slideItems.length ; i++) {
		var slideItem = slideItems[i];

		var slideTitleNode = _getFirstElement(slideItem, "title");
		var slideTitle = _getElementText(slideTitleNode);

		var slideId = _getAttribute(slideItem, "identifier");

		var slideIdRef = _getAttribute(slideItem, "identifierref");

		var slideHref = _readHref(slideIdRef);

//		alert(slideHref);
		
		var subslideItems = _getChildNodesByName(slideItem, "item");

		var kwrds = _getKeywords(slideItem);
		
		slideArray[slideArray.length] = new Slide(slideId, slideTitle, slideHref, subslideItems, kwrds);
	}

	return slideArray;
}

Lecture.prototype.getId = function() {
	return this.id;
}

Lecture.prototype.getTitle = function() {
	return this.title;
}

Lecture.prototype.getSlides = function() {
	return this.slides;
}

Lecture.prototype.getOrder = function() {
	return this.order;
}

Lecture.prototype.getSlideById = function(slideId) {
	
	for (var i=0; i<this.slides.length ; i++ ) {

		if (slideId == this.slides[i].getId() ) {
			return this.slides[i];
		}
	}
}

Lecture.prototype.getSlideByOrder = function(order) {
	return this.slides[order];
}

Lecture.prototype.getSlidesCount = function() {
	return this.slides.length;
}

Lecture.prototype.getFirstSlide = function() {
	return this.slides[0];
}

Lecture.prototype.getLastSlide = function() {
	return this.slides[this.slides.length - 1];
}

Lecture.prototype.getAllKeywords = function() {

	var _allKwrds = new Array();

	for (var i=0 ; i<this.slides.length ; i++) {
		var _kwrds = this.slides[i].getKeywords();

		for (var j=0; j<_kwrds.length ; j++ ) {
			_allKwrds[_allKwrds.length] = _kwrds[j];
		}
	}

	return _allKwrds;
}

Lecture.prototype.getSlidesIdByKwrd = function(kwrd) {

	var slidesId = new Array();

	for (var i=0 ; i<this.slides.length ; i++) {
		if (this.slides[i].containsKwrd(kwrd)) slidesId[slidesId.length] = this.slides[i].getId(); 
		
	}

	return slidesId;
}




// Slide class ---------------------------------------------------------------------

function Slide(id, title, href, subSlideItems,  keywords) {
	this.id = id;
	this.title = title;
	this.href = href;
	this.keywords = keywords;

	this.loadSubslides(subSlideItems);

//	this.order = order;

}

Slide.prototype.loadSubslides = function(subSlideItems) {

	var subslideArray = new Array();

	for (var i=0; i<subSlideItems.length ; i++) {
		var subSlideItem = subSlideItems[i];

		var subSlideIdRef = _getAttribute(subSlideItem, "identifierref");

		var subSlideHref = _readHref(subSlideIdRef);

		if (subSlideIdRef.indexOf("assessment") != -1) {
			this.assess = subSlideHref;
		} else 	if (subSlideIdRef.indexOf("task") != -1) {
					this.task = subSlideHref;
				} else 	if (subSlideIdRef.indexOf("media") != -1) {
							if (_getMediaType(subSlideHref) == "audio") {
								this.audio = subSlideHref;
							} else {
								this.video = subSlideHref;	
							}

							this.mimeType = _getMimeType(subSlideHref);
						}

		

//		alert(this.title + " -> " + subSlideHref + " -> " + this.assess + this.task + this.media);
	}

}


Slide.prototype.getId = function() {
	return this.id;
}

Slide.prototype.getTitle = function() {
	return this.title;
}

Slide.prototype.getHref = function() {
	return this.href;
}

Slide.prototype.getTask = function() {
	return this.task;
}
Slide.prototype.getAssess = function() {
	return this.assess;
}
Slide.prototype.getVideo = function() {
	return this.video;
}
Slide.prototype.getAudio = function() {
	return this.audio;
}

Slide.prototype.getMimeType = function() {
	return this.mimeType;
}

/*
Slide.prototype.getOrder = function() {
	return this.order;
}
*/

Slide.prototype.getKeywords = function() {
	return this.keywords;
}

Slide.prototype.containsKwrd = function(kwrd) {
	return _contains(this.keywords, kwrd);
}

Slide.prototype.hasKeywords = function () {
	return (this.keywords.length == 0) ? false : true;
}


// ----------------  TOOLS --------------------------------------------------------------------------
function _getMediaType(_media) {

	if(_media != '') {

		var _ext	= _getFileExtension(_media);

		switch(_ext) {

			case	'wav':
			case	'mp1':
			case	'mp2':
			case	'mp3':
			case	'wma':
			case	'au':
			case	'wax':
			case	'aif':
			case	'aifc':
			case	'aiff':
			case	'snd':	

				return 'audio';

			case	'mpg':
			case	'mpeg':
			case	'avi':
			case	'asf':
			case	'asx':
			case	'wmv':
			case	'wm':
			case	'wmx':
			case	'wmp':
			case	'wvx':
			case	'mpe':
			case	'mpv2':
			case	'mp2v':
			

				return 'video';
				
			default:
			
				return 'unknown';
		}
	} else	return 'none';
}

function _getMimeType(_media) {

		var _ext	= _getFileExtension(_media);

		switch(_ext) {

			// audio
			case 'wav':  return "audio/x-wav";
			case 'mp2':  return "audio/mpeg";
			case 'mp3':  return "audio/mpeg";
			case 'wma':  return "audio/x-ms-wma";
			case 'au':   return "audio/basic";
			case 'wax':  return "video/x-ms-wax";
			case 'aif':  return "audio/x-aiff";
			case 'aifc': return "audio/x-aiff";
			case 'aiff': return "audio/x-aiff";
			case 'snd':  return "audio/basic";

			//video
			case 'mpg':  return "video/mpeg";
			case 'mpeg': return "video/mpeg";
			case 'avi':  return "video/x-msvideo";
			case 'asf':  return "video/x-ms-asf";
			case 'asx':  return "video/x-ms-asx";
			case 'wmv':  return "video/x-ms-wmv";
			case 'wmx':  return "video/x-ms-wmx";
			case 'wmp':  return "video/x-ms-wmp";
			case 'wvx':  return "video/x-ms-wvx";
			case 'mpg':  return "video/mpeg";
			case 'mpv2':  return "video/x-mpeg2";
			case 'mp2v':  return "video/x-mpeg2";
			

			default: return "video/mpeg";
		}
}

function _getFileExtension(_file) {

	if(_file != '') {
	
		return _file.substr(_file.lastIndexOf('.') + 1);

	} else	return '';
}


function _contains(_array, _object) {
	
//	alert(_object);

	for (var i=0; i<_array.length ; i++ ) {
		if (_array[i] == _object)  return true;
		
	}

	return false;
}

function _sortString(a,b) {
	var _a = a.toLowerCase();
	var _b = b.toLowerCase();

	if (_a < _b) return -1;
	if (_a > _b) return 1;

	return 0;
}